# SessionListResponse

A list response form the API. Contains a field \"results\" which has the contents of the response.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**results** | [**list[Session]**](Session.md) |  | 
**metadata** | [**ListResponseMetadata**](ListResponseMetadata.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


